@@ -288,7 +288,7 @@ def add_model_params_lm(info_dict):
         elif fit_algorithm == "elastic_net":
             info_dict["model"] = "Elastic Net regression"
             info_dict["alpha"] = ml_model.alpha_
-            info_dict["l1_ratio"] = ml_model.l1_ratio
+            info_dict["l1_ratio"] = ml_model.l1_ratio_
         elif fit_algorithm == "sgd":
             info_dict["model"] = "Elastic Net regression via SGD"
             info_dict["alpha"] = ml_model.alpha  # does not have underscore, because this is not cv
@@ -936,7 +936,7 @@ def get_lasso_coef_df_by_multi_sample_split(info_dict):
             confidence_intervals.append([0., 0.])
         else:
             check_index = (p_value_rankings[i] > gamma_min) & (beta_estimates[i] != 0)
-            if len(check_index) == 0:
+            if check_index.sum() == 0:
                 confidence_intervals.append([0., 0.])
             else:
                 lb = np.min(ordinary_confidence_interval_lb[i, check_index])
