@@ -30,10 +30,12 @@ import functools
 from typing import Dict
 from typing import Optional
 
+import numpy as np
 import pandas as pd
 
 from greykite.algo.forecast.silverkite.forecast_silverkite import SilverkiteForecast
 from greykite.algo.forecast.silverkite.silverkite_diagnostics import SilverkiteDiagnostics
+from greykite.common.features.timeseries_lags import build_autoreg_df_multi
 from greykite.common.python_utils import dictionaries_values_to_lists
 from greykite.common.python_utils import unique_in_list
 from greykite.common.python_utils import update_dictionaries
@@ -161,6 +163,7 @@ def apply_default_model_components(
 
     default_autoregression = {
         "autoreg_dict": [None],
+        "simulation_num": [10]
     }
     model_components.autoregression = update_dictionary(
         default_autoregression,
@@ -173,6 +176,14 @@ def apply_default_model_components(
         overwrite_dict=model_components.regressors,
         allow_unknown_keys=False)
 
+    default_lagged_regressors = {
+        "lagged_regressor_dict": [None],
+    }
+    model_components.lagged_regressors = update_dictionary(
+        default_lagged_regressors,
+        overwrite_dict=model_components.lagged_regressors,
+        allow_unknown_keys=False)
+
     default_uncertainty = {
         "uncertainty_dict": [None],
     }
@@ -193,12 +204,16 @@ def apply_default_model_components(
         # To use first date of each training split, set to `None` in model_components.
         "origin_for_time_vars": [origin_for_time_vars],
         "extra_pred_cols": ["ct1"],  # linear growth
+        "drop_pred_cols": [None],
+        "explicit_pred_cols": [None],
         "fit_algorithm_dict": [{
             "fit_algorithm": "linear",
             "fit_algorithm_params": None,
         }],
         "min_admissible_value": [None],
         "max_admissible_value": [None],
+        "regression_weight_col": [None],
+        "normalize_method": [None]
     }
     model_components.custom = update_dictionary(
         default_custom,
@@ -289,15 +304,20 @@ class SilverkiteTemplate(BaseTemplate):
             autoregression: `dict` [`str`, `any`] or None, optional
                 Specifies the autoregression configuration. Dictionary with the following optional key:
 
-                ``"autoreg_dict"`` : `dict` or None or a list of such values for grid search
-                    A dictionary with arguments for `~greykite.common.features.timeseries_lags.build_autoreg_df`.
+                ``"autoreg_dict"``: `dict` or `str` or None or a list of such values for grid search
+                    If a `dict`: A dictionary with arguments for `~greykite.common.features.timeseries_lags.build_autoreg_df`.
                     That function's parameter ``value_col`` is inferred from the input of
-                    current function ``forecast_silverkite``. Other keys are:
+                    current function ``self.forecast``. Other keys are:
 
-                        * ``"lag_dict"`` : `dict` or None
-                        * ``"agg_lag_dict"`` : `dict` or None
-                        * ``"series_na_fill_func"`` : callable
+                        ``"lag_dict"`` : `dict` or None
+                        ``"agg_lag_dict"`` : `dict` or None
+                        ``"series_na_fill_func"`` : callable
 
+                    If a `str`: The string will represent a method and a dictionary will be
+                    constructed using that `str`.
+                    Currently only implemented method is "auto" which uses
+                    `~greykite.algo.forecast.silverkite.SilverkiteForecast.__get_default_autoreg_dict`
+                    to create a dictionary.
                     See more details for above parameters in
                     `~greykite.common.features.timeseries_lags.build_autoreg_df`.
 
@@ -306,6 +326,37 @@ class SilverkiteTemplate(BaseTemplate):
 
                 Allowed keys: None. (Use ``model_components.custom["extra_pred_cols"]`` to specify
                 regressors.)
+            lagged_regressors: `dict` [`str`, `dict`] or None, optional
+                Specifies the lagged regressors configuration. Dictionary with the following optional key:
+
+                ``"lagged_regressor_dict"``: `dict` or None or a list of such values for grid search
+                    A dictionary with arguments for `~greykite.common.features.timeseries_lags.build_autoreg_df_multi`.
+                    The keys of the dictionary are the target lagged regressor column names.
+                    It can leverage the regressors included in ``df``.
+                    The value of each key is either a `dict` or `str`.
+                    If `dict`, it has the following keys:
+
+                        ``"lag_dict"`` : `dict` or None
+                        ``"agg_lag_dict"`` : `dict` or None
+                        ``"series_na_fill_func"`` : callable
+
+                    If `str`, it represents a method and a dictionary will be constructed using that `str`.
+                    Currently the only implemented method is "auto" which uses ``SilverkiteForecast``'s
+                    `~greykite.algo.forecast.silverkite.SilverkiteForecast.__get_default_lagged_regressor_dict`
+                    to create a dictionary for each lagged regressor.
+                    An example::
+
+                        lagged_regressor_dict = {
+                            "regressor1": {
+                                "lag_dict": {"orders": [1, 2, 3]},
+                                "agg_lag_dict": {
+                                    "orders_list": [[7, 7 * 2, 7 * 3]],
+                                    "interval_list": [(8, 7 * 2)]},
+                                "series_na_fill_func": lambda s: s.bfill().ffill()},
+                            "regressor2": "auto"}
+
+                    Check the docstring of `~greykite.common.features.timeseries_lags.build_autoreg_df_multi`
+                    for more details for each argument.
             uncertainty: `dict` [`str`, `any`] or None, optional
                 How to model the uncertainty. A dictionary with keys corresponding to
                 parameters in `~greykite.algo.forecast.silverkite.forecast_silverkite.SilverkiteForecast.forecast`.
@@ -315,8 +366,12 @@ class SilverkiteTemplate(BaseTemplate):
                 Custom parameters that don't fit the categories above. A dictionary with keys corresponding to
                 parameters in `~greykite.algo.forecast.silverkite.forecast_silverkite.SilverkiteForecast.forecast`.
 
-                Allowed keys: ``"silverkite"``, ``"silverkite_diagnostics"``, ``"origin_for_time_vars"``, ``"extra_pred_cols"``,
-                ``"fit_algorithm_dict"``, ``"min_admissible_value"``, ``"max_admissible_value"``.
+                Allowed keys:
+                    ``"silverkite"``, ``"silverkite_diagnostics"``,
+                    ``"origin_for_time_vars"``, ``"extra_pred_cols"``,
+                    ``"drop_pred_cols"``, ``"explicit_pred_cols"``,
+                    ``"fit_algorithm_dict"``, ``"min_admissible_value"``,
+                    ``"max_admissible_value"``.
 
                 .. note::
 
@@ -411,6 +466,93 @@ class SilverkiteTemplate(BaseTemplate):
             regressor_cols = None
         return regressor_cols
 
+    def get_lagged_regressor_info(self):
+        """Returns lagged regressor column names and minimal/maximal lag order. The lag order
+        can be used to check potential imputation in the computation of lags.
+
+        Implements the method in `~greykite.framework.templates.base_template.BaseTemplate`.
+
+        Returns
+        -------
+        lagged_regressor_info : `dict`
+            A dictionary that includes the lagged regressor column names and maximal/minimal lag order
+            The keys are:
+
+                lagged_regressor_cols : `list` [`str`] or None
+                    See `~greykite.framework.pipeline.pipeline.forecast_pipeline`.
+                overall_min_lag_order : `int` or None
+                overall_max_lag_order : `int` or None
+
+            For example::
+
+                self.config.model_components_param.lagged_regressors["lagged_regressor_dict"] = [
+                    {"regressor1": {
+                        "lag_dict": {"orders": [7]},
+                        "agg_lag_dict": {
+                            "orders_list": [[7, 7 * 2, 7 * 3]],
+                            "interval_list": [(8, 7 * 2)]},
+                        "series_na_fill_func": lambda s: s.bfill().ffill()}
+                    },
+                    {"regressor2": {
+                        "lag_dict": {"orders": [2]},
+                        "agg_lag_dict": {
+                            "orders_list": [[7, 7 * 2]],
+                            "interval_list": [(8, 7 * 2)]},
+                        "series_na_fill_func": lambda s: s.bfill().ffill()}
+                    },
+                    {"regressor3": "auto"}
+                ]
+
+            Then the function returns::
+
+                lagged_regressor_info = {
+                    "lagged_regressor_cols": ["regressor1", "regressor2", "regressor3"],
+                    "overall_min_lag_order": 2,
+                    "overall_max_lag_order": 21
+                }
+
+            Note that "regressor3" is skipped as the "auto" option makes sure the lag order is proper.
+        """
+        lagged_regressor_info = {
+            "lagged_regressor_cols": None,
+            "overall_min_lag_order": None,
+            "overall_max_lag_order": None
+        }
+        if (self.config is None or self.config.model_components_param is None or
+                self.config.model_components_param.lagged_regressors is None):
+            return lagged_regressor_info
+
+        lag_reg_dict = self.config.model_components_param.lagged_regressors.get("lagged_regressor_dict", None)
+        if lag_reg_dict is None or lag_reg_dict == [None]:
+            return lagged_regressor_info
+
+        lag_reg_dict_list = [lag_reg_dict] if isinstance(lag_reg_dict, dict) else lag_reg_dict
+        lagged_regressor_cols = []
+        overall_min_lag_order = np.inf
+        overall_max_lag_order = -np.inf
+        for d in lag_reg_dict_list:
+            if isinstance(d, dict):
+                lagged_regressor_cols += list(d.keys())
+                # Also gets the minimal lag order for each lagged_regressor_dict.
+                # Looks at each individual regressor column, "auto" is skipped because
+                # "auto" always makes sure that minimal lag order is at least forecast horizon.
+                for key, value in d.items():
+                    if isinstance(value, dict):
+                        d_tmp = {key: value}
+                        lag_reg_components = build_autoreg_df_multi(value_lag_info_dict=d_tmp)
+                        overall_min_lag_order = min(
+                            lag_reg_components["min_order"],
+                            overall_min_lag_order)
+                        overall_max_lag_order = max(
+                            lag_reg_components["max_order"],
+                            overall_max_lag_order)
+        lagged_regressor_cols = list(set(lagged_regressor_cols))
+
+        lagged_regressor_info["lagged_regressor_cols"] = lagged_regressor_cols
+        lagged_regressor_info["overall_min_lag_order"] = overall_min_lag_order
+        lagged_regressor_info["overall_max_lag_order"] = overall_max_lag_order
+        return lagged_regressor_info
+
     def get_hyperparameter_grid(self):
         """Returns hyperparameter grid.
 
@@ -447,17 +589,23 @@ class SilverkiteTemplate(BaseTemplate):
             "estimator__silverkite_diagnostics": self.config.model_components_param.custom["silverkite_diagnostics"],
             "estimator__origin_for_time_vars": self.config.model_components_param.custom["origin_for_time_vars"],
             "estimator__extra_pred_cols": self.config.model_components_param.custom["extra_pred_cols"],
+            "estimator__drop_pred_cols": self.config.model_components_param.custom["drop_pred_cols"],
+            "estimator__explicit_pred_cols": self.config.model_components_param.custom["explicit_pred_cols"],
             "estimator__train_test_thresh": [None],
             "estimator__training_fraction": [None],
             "estimator__fit_algorithm_dict": self.config.model_components_param.custom["fit_algorithm_dict"],
             "estimator__daily_event_df_dict": self.config.model_components_param.events["daily_event_df_dict"],
             "estimator__fs_components_df": self.config.model_components_param.seasonality["fs_components_df"],
             "estimator__autoreg_dict": self.config.model_components_param.autoregression["autoreg_dict"],
+            "estimator__simulation_num": self.config.model_components_param.autoregression["simulation_num"],
+            "estimator__lagged_regressor_dict": self.config.model_components_param.lagged_regressors["lagged_regressor_dict"],
             "estimator__changepoints_dict": self.config.model_components_param.changepoints["changepoints_dict"],
             "estimator__seasonality_changepoints_dict": self.config.model_components_param.changepoints["seasonality_changepoints_dict"],
             "estimator__changepoint_detector": [None],
             "estimator__min_admissible_value": self.config.model_components_param.custom["min_admissible_value"],
             "estimator__max_admissible_value": self.config.model_components_param.custom["max_admissible_value"],
+            "estimator__normalize_method": self.config.model_components_param.custom["normalize_method"],
+            "estimator__regression_weight_col": self.config.model_components_param.custom["regression_weight_col"],
             "estimator__uncertainty_dict": self.config.model_components_param.uncertainty["uncertainty_dict"],
         }
 
