@@ -29,7 +29,10 @@ import dataclasses
 import warnings
 from typing import Type
 
+import numpy as np
+
 from greykite.algo.forecast.silverkite.constants.silverkite_holiday import SilverkiteHoliday
+from greykite.common.features.timeseries_lags import build_autoreg_df_multi
 from greykite.common.python_utils import dictionaries_values_to_lists
 from greykite.common.python_utils import unique_dict_in_list
 from greykite.common.python_utils import unique_in_list
@@ -286,20 +289,30 @@ class SimpleSilverkiteTemplate(BaseTemplate):
                         are passed with the class automatically.
 
             autoregression: `dict` [`str`, `dict`] or None, optional
-                Specifies the autoregression configuration. Dictionary with the following optional key:
+                Specifies the autoregression configuration. Dictionary with the following optional keys:
 
-                ``"autoreg_dict"``: `dict` or None or a list of such values for grid search
-                    A dictionary with arguments for `~greykite.common.features.timeseries_lags.build_autoreg_df`.
+                ``"autoreg_dict"``: `dict` or `str` or None or a list of such values for grid search
+                    If a `dict`: A dictionary with arguments for `~greykite.common.features.timeseries_lags.build_autoreg_df`.
                     That function's parameter ``value_col`` is inferred from the input of
-                    current function ``forecast_silverkite``. Other keys are:
+                    current function ``self.forecast``. Other keys are:
 
-                        * ``"lag_dict"`` : `dict` or None
-                        * ``"agg_lag_dict"`` : `dict` or None
-                        * ``"series_na_fill_func"`` : callable
+                        ``"lag_dict"`` : `dict` or None
+                        ``"agg_lag_dict"`` : `dict` or None
+                        ``"series_na_fill_func"`` : callable
 
+                    If a `str`: The string will represent a method and a dictionary will be
+                    constructed using that `str`.
+                    Currently only implemented method is "auto" which uses
+                    `~greykite.algo.forecast.silverkite.SilverkiteForecast.__get_default_autoreg_dict`
+                    to create a dictionary.
                     See more details for above parameters in
                     `~greykite.common.features.timeseries_lags.build_autoreg_df`.
 
+                ``"simulation_num"`` :  `int`, default 10
+                    The number of simulations to use. Applies only if any of the lags in ``autoreg_dict``
+                    are smaller than ``forecast_horizon``. In that case, simulations are needed to generate
+                    forecasts and prediction intervals.
+
             regressors: `dict` [`str`, `any`] or None, optional
                 Specifies the regressors to include in the model (e.g. macro-economic factors).
                 Dictionary with the following optional keys:
@@ -314,6 +327,38 @@ class SimpleSilverkiteTemplate(BaseTemplate):
 
                 Use ``extra_pred_cols`` to specify interactions of any model terms with the regressors.
 
+            lagged_regressors: `dict` [`str`, `dict`] or None, optional
+                Specifies the lagged regressors configuration. Dictionary with the following optional key:
+
+                ``"lagged_regressor_dict"``: `dict` or None or a list of such values for grid search
+                    A dictionary with arguments for `~greykite.common.features.timeseries_lags.build_autoreg_df_multi`.
+                    The keys of the dictionary are the target lagged regressor column names.
+                    It can leverage the regressors included in ``df``.
+                    The value of each key is either a `dict` or `str`.
+                    If `dict`, it has the following keys:
+
+                        ``"lag_dict"`` : `dict` or None
+                        ``"agg_lag_dict"`` : `dict` or None
+                        ``"series_na_fill_func"`` : callable
+
+                    If `str`, it represents a method and a dictionary will be constructed using that `str`.
+                    Currently the only implemented method is "auto" which uses ``SilverkiteForecast``'s
+                    `~greykite.algo.forecast.silverkite.SilverkiteForecast.__get_default_lagged_regressor_dict`
+                    to create a dictionary for each lagged regressor.
+                    An example::
+
+                        lagged_regressor_dict = {
+                            "regressor1": {
+                                "lag_dict": {"orders": [1, 2, 3]},
+                                "agg_lag_dict": {
+                                    "orders_list": [[7, 7 * 2, 7 * 3]],
+                                    "interval_list": [(8, 7 * 2)]},
+                                "series_na_fill_func": lambda s: s.bfill().ffill()},
+                            "regressor2": "auto"}
+
+                    Check the docstring of `~greykite.common.features.timeseries_lags.build_autoreg_df_multi`
+                    for more details for each argument.
+
             uncertainty: `dict` [`str`, `dict`] or None, optional
                 Along with ``coverage``, specifies the uncertainty interval configuration. Use ``coverage``
                 to set interval size. Use ``uncertainty`` to tune the calculation.
@@ -426,6 +471,15 @@ class SimpleSilverkiteTemplate(BaseTemplate):
                     generated by ``build_silverkite_features`` or included with input data.
                     These are added to any features already included by ``feature_sets_enabled`` and
                     terms specified by ``model``.
+                ``"drop_pred_cols"`` : `list` [`str`] or None, default None
+                    Names of predictor columns to be dropped from the final model.
+                    Ignored if None.
+                ``"explicit_pred_cols"`` : `list` [`str`] or None, default None
+                    Names of the explicit predictor columns which will be
+                    the only variables in the final model. Note that this overwrites
+                    the generated predictors in the model and may include new
+                    terms not appearing in the predictors (e.g. interaction terms).
+                    Ignored if None.
                 ``"min_admissible_value"``: `float` or `double` or `int` or None, default None
                     The lowest admissible value for the forecasts and prediction
                     intervals. Any value below this will be mapped back to this value.
@@ -434,6 +488,9 @@ class SimpleSilverkiteTemplate(BaseTemplate):
                     The highest admissible value for the forecasts and prediction
                     intervals. Any value above this will be mapped back to this value.
                     If None, there is no upper bound.
+                ``"normalize_method"``: `str` or None, default None
+                    The normalization method for feature matrix.
+                    Available values are "statistical" and "min_max".
 
             hyperparameter_override: `dict` [`str`, `any`] or None or `list` [`dict` [`str`, `any`] or None], optional
                 After the above model components are used to create a hyperparameter grid, the result is
@@ -559,6 +616,93 @@ class SimpleSilverkiteTemplate(BaseTemplate):
             array=regressor_cols,
             ignored_elements=(None,))
 
+    def get_lagged_regressor_info(self):
+        """Returns lagged regressor column names and minimal/maximal lag order. The lag order
+        can be used to check potential imputation in the computation of lags.
+
+        Implements the method in `~greykite.framework.templates.base_template.BaseTemplate`.
+
+        Returns
+        -------
+        lagged_regressor_info : `dict`
+            A dictionary that includes the lagged regressor column names and maximal/minimal lag order
+            The keys are:
+
+                lagged_regressor_cols : `list` [`str`] or None
+                    See `~greykite.framework.pipeline.pipeline.forecast_pipeline`.
+                overall_min_lag_order : `int` or None
+                overall_max_lag_order : `int` or None
+
+            For example::
+
+                self.config.model_components_param.lagged_regressors["lagged_regressor_dict"] = [
+                    {"regressor1": {
+                        "lag_dict": {"orders": [7]},
+                        "agg_lag_dict": {
+                            "orders_list": [[7, 7 * 2, 7 * 3]],
+                            "interval_list": [(8, 7 * 2)]},
+                        "series_na_fill_func": lambda s: s.bfill().ffill()}
+                    },
+                    {"regressor2": {
+                        "lag_dict": {"orders": [2]},
+                        "agg_lag_dict": {
+                            "orders_list": [[7, 7 * 2]],
+                            "interval_list": [(8, 7 * 2)]},
+                        "series_na_fill_func": lambda s: s.bfill().ffill()}
+                    },
+                    {"regressor3": "auto"}
+                ]
+
+            Then the function returns::
+
+                lagged_regressor_info = {
+                    "lagged_regressor_cols": ["regressor1", "regressor2", "regressor3"],
+                    "overall_min_lag_order": 2,
+                    "overall_max_lag_order": 21
+                }
+
+            Note that "regressor3" is skipped as the "auto" option makes sure the lag order is proper.
+        """
+        lagged_regressor_info = {
+            "lagged_regressor_cols": None,
+            "overall_min_lag_order": None,
+            "overall_max_lag_order": None
+        }
+        if (self.config is None or self.config.model_components_param is None or
+                self.config.model_components_param.lagged_regressors is None):
+            return lagged_regressor_info
+
+        lag_reg_dict = self.config.model_components_param.lagged_regressors.get("lagged_regressor_dict", None)
+        if lag_reg_dict is None or lag_reg_dict == [None]:
+            return lagged_regressor_info
+
+        lag_reg_dict_list = [lag_reg_dict] if isinstance(lag_reg_dict, dict) else lag_reg_dict
+        lagged_regressor_cols = []
+        overall_min_lag_order = np.inf
+        overall_max_lag_order = -np.inf
+        for d in lag_reg_dict_list:
+            if isinstance(d, dict):
+                lagged_regressor_cols += list(d.keys())
+                # Also gets the minimal lag order for each lagged_regressor_dict.
+                # Looks at each individual regressor column, "auto" is skipped because
+                # "auto" always makes sure that minimal lag order is at least forecast horizon.
+                for key, value in d.items():
+                    if isinstance(value, dict):
+                        d_tmp = {key: value}
+                        lag_reg_components = build_autoreg_df_multi(value_lag_info_dict=d_tmp)
+                        overall_min_lag_order = min(
+                            lag_reg_components["min_order"],
+                            overall_min_lag_order)
+                        overall_max_lag_order = max(
+                            lag_reg_components["max_order"],
+                            overall_max_lag_order)
+        lagged_regressor_cols = list(set(lagged_regressor_cols))
+
+        lagged_regressor_info["lagged_regressor_cols"] = lagged_regressor_cols
+        lagged_regressor_info["overall_min_lag_order"] = overall_min_lag_order
+        lagged_regressor_info["overall_max_lag_order"] = overall_max_lag_order
+        return lagged_regressor_info
+
     def get_hyperparameter_grid(self):
         """Returns hyperparameter grid.
 
@@ -717,8 +861,12 @@ class SimpleSilverkiteTemplate(BaseTemplate):
             The processed template name. For example, the input above will become
             `DAILY_SEAS_LT_GR_LINEAR_CP_LT_HOL_NONE_FEASET_OFF_ALGO_LINEAR_AR_ON`.
         """
-        if template == "SILVERKITE":
-            return "SILVERKITE"
+        if template in ("SILVERKITE",
+                        "SILVERKITE_WITH_AR",
+                        "SILVERKITE_DAILY_1_CONFIG_1",
+                        "SILVERKITE_DAILY_1_CONFIG_2",
+                        "SILVERKITE_DAILY_1_CONFIG_3"):
+            return template
         if template == "SILVERKITE_EMPTY":
             return self.constants.SILVERKITE_EMPTY
         if isinstance(template, str):
@@ -806,13 +954,19 @@ class SimpleSilverkiteTemplate(BaseTemplate):
         template_type : `str`
             "single" or "multi".
         """
-        if (template in ["SILVERKITE", "SILVERKITE_EMPTY"]
+        if (template in ["SILVERKITE",
+                         "SILVERKITE_WITH_AR",
+                         "SILVERKITE_DAILY_1_CONFIG_1",
+                         "SILVERKITE_DAILY_1_CONFIG_2",
+                         "SILVERKITE_DAILY_1_CONFIG_3",
+                         "SILVERKITE_EMPTY"]
                 or isinstance(template, self.constants.SimpleSilverkiteTemplateOptions)
                 or template.split("_")[0] in self.constants.VALID_FREQ):
             return "single"
         if template in self.constants.MULTI_TEMPLATES:
             return "multi"
-        raise ValueError(f"The template name {template} is not recognized. It must be 'SILVERKITE', 'SILVERKITE_EMPTY', "
+        raise ValueError(f"The template name {template} is not recognized. It must be 'SILVERKITE', 'SILVERKITE_WITH_AR', "
+                         f"'SILVERKITE_DAILY_1_CONFIG_1', 'SILVERKITE_DAILY_1_CONFIG_2', 'SILVERKITE_DAILY_1_CONFIG_3', 'SILVERKITE_EMPTY', "
                          f"a `SimpleSilverkiteTemplateOptions` data class, of the type"
                          " '{FREQ}_SEAS_{VAL}_GR_{VAL}_CP_{VAL}_HOL_{VAL}_FEASET_{VAL}_ALGO_{VAL}_AR_{VAL}' or"
                          f" belong to {list(self.constants.MULTI_TEMPLATES.keys())}.")
@@ -887,6 +1041,14 @@ class SimpleSilverkiteTemplate(BaseTemplate):
         """
         if template == "SILVERKITE":
             return self.constants.SILVERKITE
+        if template == "SILVERKITE_WITH_AR":
+            return self.constants.SILVERKITE_WITH_AR
+        if template == "SILVERKITE_DAILY_1_CONFIG_1":
+            return self.constants.SILVERKITE_DAILY_1_CONFIG_1
+        if template == "SILVERKITE_DAILY_1_CONFIG_2":
+            return self.constants.SILVERKITE_DAILY_1_CONFIG_2
+        if template == "SILVERKITE_DAILY_1_CONFIG_3":
+            return self.constants.SILVERKITE_DAILY_1_CONFIG_3
         names = template.split("_")
         freq, components = names[0], names[1:]
         # The value of a keyword is supposed to follow it.
@@ -905,13 +1067,20 @@ class SimpleSilverkiteTemplate(BaseTemplate):
                 "max_daily_seas_interaction_order": self.constants.COMMON_MODELCOMPONENTPARAM_PARAMETERS["DSI"][freq][components[components.index("DSI")+1]],
                 "max_weekly_seas_interaction_order": self.constants.COMMON_MODELCOMPONENTPARAM_PARAMETERS["WSI"][freq][components[components.index("WSI")+1]],
                 "extra_pred_cols": [],
+                "drop_pred_cols": None,
+                "explicit_pred_cols": None,
                 "min_admissible_value": None,
-                "max_admissible_value": None
+                "max_admissible_value": None,
+                "regression_weight_col": None,
+                "normalize_method": None
             },
             autoregression=self.constants.COMMON_MODELCOMPONENTPARAM_PARAMETERS["AR"][components[components.index("AR")+1]],
             regressors={
                 "regressor_cols": []
             },
+            lagged_regressors={
+                "lagged_regressor_dict": None
+            },
             uncertainty={
                 "uncertainty_dict": None
             })
@@ -967,7 +1136,8 @@ class SimpleSilverkiteTemplate(BaseTemplate):
             default_model_components.hyperparameter_override = {}
         if model_components is None:
             return default_model_components
-        components = ["seasonality", "growth", "changepoints", "events", "custom", "autoregression", "regressors", "uncertainty", "hyperparameter_override"]
+        components = ["seasonality", "growth", "changepoints", "events", "custom", "autoregression",
+                      "regressors", "lagged_regressors", "uncertainty", "hyperparameter_override"]
         for component in components:
             allow_unknown_keys = (component == "hyperparameter_override")  # Allows unknown keys for hyperparameter_override.
             updated_value = update_dictionaries(
@@ -1053,10 +1223,16 @@ class SimpleSilverkiteTemplate(BaseTemplate):
             "estimator__max_daily_seas_interaction_order": model_components.custom["max_daily_seas_interaction_order"],
             "estimator__max_weekly_seas_interaction_order": model_components.custom["max_weekly_seas_interaction_order"],
             "estimator__extra_pred_cols": model_components.custom["extra_pred_cols"],
+            "estimator__drop_pred_cols": model_components.custom["drop_pred_cols"],
+            "estimator__explicit_pred_cols": model_components.custom["explicit_pred_cols"],
             "estimator__min_admissible_value": model_components.custom["min_admissible_value"],
             "estimator__max_admissible_value": model_components.custom["max_admissible_value"],
+            "estimator__normalize_method": model_components.custom["normalize_method"],
             "estimator__autoreg_dict": model_components.autoregression["autoreg_dict"],
+            "estimator__simulation_num": model_components.autoregression["simulation_num"],
             "estimator__regressor_cols": model_components.regressors["regressor_cols"],
+            "estimator__lagged_regressor_dict": model_components.lagged_regressors["lagged_regressor_dict"],
+            "estimator__regression_weight_col": model_components.custom["regression_weight_col"],
             "estimator__uncertainty_dict": model_components.uncertainty["uncertainty_dict"]
         }
         return hyperparameter_grid
