@@ -1,4 +1,5 @@
 import pickle
+import sys
 
 import numpy as np
 import pandas as pd
@@ -29,6 +30,12 @@ from greykite.framework.templates.model_templates import ModelTemplateEnum
 from greykite.sklearn.cross_validation import RollingTimeSeriesSplit
 
 
+try:
+    import fbprophet  # noqa
+except ModuleNotFoundError:
+    pass
+
+
 @pytest.fixture(scope="module")
 def df():
     data = generate_df_with_reg_for_tests(
@@ -214,6 +221,8 @@ def valid_bm(df, valid_configs, custom_tscv):
     return bm
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_benchmark_class_init(df, valid_configs, custom_tscv):
     forecaster = Forecaster()
     bm = BenchmarkForecastConfig(df=df, configs=valid_configs, tscv=custom_tscv, forecaster=forecaster)
@@ -230,6 +239,8 @@ def test_benchmark_class_init(df, valid_configs, custom_tscv):
         BenchmarkForecastConfig(tscv=custom_tscv)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_validate(df, valid_configs, custom_tscv):
     bm = BenchmarkForecastConfig(df=df, configs=valid_configs, tscv=custom_tscv)
     bm.validate()
@@ -273,6 +284,8 @@ def test_validate(df, valid_configs, custom_tscv):
         bm.validate()
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_run(valid_bm, valid_configs):
     bm = valid_bm
 
@@ -294,6 +307,8 @@ def test_run(valid_bm, valid_configs):
             assert pipeline_result.forecast is not None
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_extract_forecasts(valid_bm, df, valid_configs, custom_tscv):
     bm = valid_bm
     bm.extract_forecasts()
@@ -330,6 +345,8 @@ def test_extract_forecasts(valid_bm, df, valid_configs, custom_tscv):
         bm.extract_forecasts()
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_plot_forecasts_by_step(valid_bm):
     bm = valid_bm
 
@@ -339,6 +356,7 @@ def test_plot_forecasts_by_step(valid_bm):
     assert fig.layout.xaxis.title.text == TIME_COL
     assert fig.layout.yaxis.title.text == VALUE_COL
     assert fig.layout.title.text == "1-step ahead rolling forecasts"
+    assert fig.layout.title.x == 0.5
 
     # len(fig.data) = 1 + len(config_keys)
     assert len(fig.data) == 1 + len(bm.configs)
@@ -359,6 +377,7 @@ def test_plot_forecasts_by_step(valid_bm):
     assert fig.layout.xaxis.title.text == "xlab"
     assert fig.layout.yaxis.title.text == "ylab"
     assert fig.layout.title.text == "title"
+    assert fig.layout.title.x == 0.5
 
     # len(fig.data) = 1 + len(config_names)
     assert len(fig.data) == 1 + 1
@@ -377,6 +396,8 @@ def test_plot_forecasts_by_step(valid_bm):
         bm.plot_forecasts_by_step(forecast_step=forecast_step)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_plot_forecasts_by_config(valid_bm):
     bm = valid_bm
 
@@ -386,6 +407,7 @@ def test_plot_forecasts_by_config(valid_bm):
     assert fig.layout.xaxis.title.text == TIME_COL
     assert fig.layout.yaxis.title.text == VALUE_COL
     assert fig.layout.title.text == "Rolling forecast for valid_prophet"
+    assert fig.layout.title.x == 0.5
     assert len(fig.data) == 1 + bm.tscv.max_splits  # len(fig.data) = 1 + number of splits
 
     assert fig.data[0].name == ACTUAL_COL
@@ -407,6 +429,7 @@ def test_plot_forecasts_by_config(valid_bm):
     assert fig.layout.xaxis.title.text == "xlab"
     assert fig.layout.yaxis.title.text == "ylab"
     assert fig.layout.title.text == "title"
+    assert fig.layout.title.x == 0.5
 
     assert fig.data[0].name == ACTUAL_COL
     assert fig.data[0].line.color == default_color
@@ -420,6 +443,8 @@ def test_plot_forecasts_by_config(valid_bm):
         bm.plot_forecasts_by_config(config_name="missing_config")
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_get_evaluation_metrics(valid_bm, metric_dict, df, valid_configs, custom_tscv):
     bm = valid_bm
 
@@ -473,6 +498,8 @@ def test_get_evaluation_metrics(valid_bm, metric_dict, df, valid_configs, custom
         bm.get_evaluation_metrics(metric_dict=metric_dict)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_plot_evaluation_metrics(valid_bm, metric_dict):
     bm = valid_bm
 
@@ -485,6 +512,7 @@ def test_plot_evaluation_metrics(valid_bm, metric_dict):
         assert fig.layout.xaxis.title.text is None
         assert fig.layout.yaxis.title.text == "Metric value"
         assert fig.layout.title.text == "Average evaluation metric across rolling windows"
+        assert fig.layout.title.x == 0.5
         assert len(fig.data) == len(bm.configs)
 
         expected_xaxis = set()
@@ -512,12 +540,15 @@ def test_plot_evaluation_metrics(valid_bm, metric_dict):
         assert fig.layout.xaxis.title.text == "xlab"
         assert fig.layout.yaxis.title.text == "ylab"
         assert fig.layout.title.text == "title"
+        assert fig.layout.title.x == 0.5
         assert len(fig.data) == len(config_names)
 
         assert fig.data[0].name == "valid_prophet"
         assert_equal(set(fig.data[0].x), expected_xaxis)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_get_grouping_evaluation(valid_bm, metric_dict, df, valid_configs, custom_tscv):
     bm = valid_bm
 
@@ -594,6 +625,8 @@ def test_get_grouping_evaluation(valid_bm, metric_dict, df, valid_configs, custo
         bm.get_grouping_evaluation_metrics(metric_dict=metric_dict)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_plot_grouping_evaluation(valid_bm, metric_dict):
     bm = valid_bm
 
@@ -606,6 +639,7 @@ def test_plot_grouping_evaluation(valid_bm, metric_dict):
     assert fig.layout.xaxis.title.text == "woy"
     assert fig.layout.yaxis.title.text == "Metric value"
     assert fig.layout.title.text == "train performance by woy across rolling windows"
+    assert fig.layout.title.x == 0.5
     assert len(fig.data) == len(bm.configs) * len(metric_dict)
 
     assert fig.data[0].name == "train MSE_valid_prophet"
@@ -628,6 +662,7 @@ def test_plot_grouping_evaluation(valid_bm, metric_dict):
     assert fig.layout.xaxis.title.text == "xlab"
     assert fig.layout.yaxis.title.text == "ylab"
     assert fig.layout.title.text == "title"
+    assert fig.layout.title.x == 0.5
     assert len(fig.data) == len(config_names) * len(metric_dict)
 
     assert fig.data[0].name == "test MSE_valid_prophet"
@@ -647,6 +682,7 @@ def test_plot_grouping_evaluation(valid_bm, metric_dict):
     assert fig.layout.xaxis.title.text == custom_column.name
     assert fig.layout.yaxis.title.text == "Metric value"
     assert fig.layout.title.text == "Error by custom group"
+    assert fig.layout.title.x == 0.5
     assert len(fig.data) == len(bm.configs) * len(metric_dict)
 
     assert fig.data[0].name == "test MSE_valid_prophet"
@@ -655,6 +691,8 @@ def test_plot_grouping_evaluation(valid_bm, metric_dict):
     assert fig.data[3].name == "test RMSE_valid_silverkite"
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_get_runtimes(valid_bm, valid_configs, custom_tscv):
     bm = valid_bm
 
@@ -681,6 +719,8 @@ def test_get_runtimes(valid_bm, valid_configs, custom_tscv):
         bm.get_runtimes()
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_plot_runtimes(valid_bm):
     bm = valid_bm
 
@@ -690,6 +730,7 @@ def test_plot_runtimes(valid_bm):
     assert fig.layout.xaxis.title.text is None
     assert fig.layout.yaxis.title.text == "Mean runtime in seconds"
     assert fig.layout.title.text == "Average runtime across rolling windows"
+    assert fig.layout.title.x == 0.5
 
     expected_xaxis = set(bm.configs)
     assert fig.data[0].name == "Runtime"
@@ -707,12 +748,15 @@ def test_plot_runtimes(valid_bm):
     assert fig.layout.xaxis.title.text == "xlab"
     assert fig.layout.yaxis.title.text == "ylab"
     assert fig.layout.title.text == "title"
+    assert fig.layout.title.x == 0.5
 
     expected_xaxis = set(config_names)
     assert fig.data[0].name == "Runtime"
     assert_equal(set(fig.data[0].x), expected_xaxis)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_get_valid_config_names(valid_bm):
     bm = valid_bm
 
@@ -732,6 +776,8 @@ def test_get_valid_config_names(valid_bm):
         assert f"Input 'config_name' ({missing_config}) is missing." in str(record.value)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_autocomplete_metric_dict(valid_bm, metric_dict):
     bm = valid_bm
     updated_metric_dict = bm.autocomplete_metric_dict(
