@@ -1,5 +1,6 @@
 import datetime
 import math
+import sys
 from functools import partial
 
 import numpy as np
@@ -21,6 +22,12 @@ from greykite.sklearn.estimator.prophet_estimator import ProphetEstimator
 from greykite.sklearn.estimator.silverkite_estimator import SilverkiteEstimator
 
 
+try:
+    import fbprophet  # noqa
+except ModuleNotFoundError:
+    pass
+
+
 @pytest.fixture
 def df():
     return pd.DataFrame({
@@ -321,6 +328,7 @@ def test_plot_grouping_evaluation(df2):
     assert fig.layout.xaxis.title.text == "dow"
     assert fig.layout.yaxis.title.text == f"train {metric_name}"
     assert fig.layout.title.text == f"train {metric_name} vs dow"
+    assert fig.layout.title.x == 0.5
     assert fig.data[0].x.shape[0] == 5
 
     # MSE, groupby_sliding_window_size, train set
@@ -335,6 +343,7 @@ def test_plot_grouping_evaluation(df2):
     assert fig.layout.xaxis.title.text == f"{cst.TIME_COL}_downsample"
     assert fig.layout.yaxis.title.text == f"train {metric_name}"
     assert fig.layout.title.text == f"train {metric_name} vs {cst.TIME_COL}_downsample"
+    assert fig.layout.title.x == 0.5
     assert fig.data[0].x.shape[0] == 3
 
     # MAE, groupby_custom_column, test set
@@ -352,6 +361,7 @@ def test_plot_grouping_evaluation(df2):
     assert fig.layout.xaxis.title.text == "custom_groups"
     assert fig.layout.yaxis.title.text == f"test {metric_name}"
     assert fig.layout.title.text == f"test {metric_name} vs custom_groups"
+    assert fig.layout.title.x == 0.5
     assert fig.data[0].x.shape[0] == 3
 
     # custom xlabel, ylabel, title
@@ -366,6 +376,7 @@ def test_plot_grouping_evaluation(df2):
     assert fig.layout.xaxis.title.text == "Custom labels"
     assert fig.layout.yaxis.title.text == "Mean Absolute Error of y"
     assert fig.layout.title.text == "Mean Absolute Error of y by Custom labels"
+    assert fig.layout.title.x == 0.5
 
 
 def test_autocomplete_map_func_dict(df2):
@@ -575,6 +586,7 @@ def test_plot_flexible_grouping_evaluation():
     assert fig.layout.xaxis.title.text == "dom"
     assert fig.layout.yaxis.title.text == metric_col
     assert fig.layout.title.text == f"{metric_col} vs dom"
+    assert fig.layout.title.x == 0.5
     assert fig.data[0].x.shape[0] == 31  # 31 unique days in month
     assert fig.data[1].line["color"] == "rgba(0, 145, 202, 1.0)"
     assert fig.data[1].fill == "tonexty"  # from auto-fill
@@ -601,6 +613,7 @@ def test_plot_flexible_grouping_evaluation():
     assert fig.layout.xaxis.title.text == "ts"
     assert fig.layout.yaxis.title.text is None
     assert fig.layout.title.text is None
+    assert fig.layout.title.x == 0.5
     assert fig.data[0].x[0] == datetime.datetime(2020, 1, 1, 0, 0)
     assert fig.data[1].line["color"] == "rgba(145, 0, 202, 1.0)"
     assert fig.data[1].fill is None
@@ -626,6 +639,7 @@ def test_plot_flexible_grouping_evaluation():
     assert fig.layout.xaxis.title.text == "x"
     assert fig.layout.yaxis.title.text == metric_col
     assert fig.layout.title.text == "custom title"
+    assert fig.layout.title.x == 0.5
     assert list(fig.data[0].x) == list("abcde")
     assert fig.data[0].line["color"] is None  # color is up to plotly
     assert fig.data[1].fill is None
@@ -672,6 +686,7 @@ def test_plot_flexible_grouping_evaluation():
         assert fig.layout.xaxis.title.text == "x value"
         assert fig.layout.yaxis.title.text == "y value"
         assert fig.layout.title.text == "error plot"
+        assert fig.layout.title.x == 0.5
         assert len(fig.data[0].x) == 7
         assert fig.data[0].mode == "lines+markers"
         assert fig.data[1].mode == "lines+markers"
@@ -702,6 +717,7 @@ def test_plot_flexible_grouping_evaluation():
     assert fig.layout.xaxis.title.text == "dow"
     assert fig.layout.yaxis.title.text == "y"
     assert fig.layout.title.text == "true vs actual by dow"
+    assert fig.layout.title.x == 0.5
     assert len(fig.data[0].x) == 7
     assert fig.layout.showlegend
 
@@ -750,14 +766,24 @@ def test_plot_components():
         assert fig.layout.yaxis3.title["text"] == "yearly"
 
         assert fig.layout.title["text"] == title
+        assert fig.layout.title["x"] == 0.5
 
         assert f"The following components have not been specified in the model: " \
                f"{{'DUMMY'}}, plotting the rest." in record[0].message.args[0]
 
+
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
+def test_plot_components_prophet():
+    X = pd.DataFrame({
+        cst.TIME_COL: pd.date_range("2018-01-01", periods=10, freq="D"),
+        cst.VALUE_COL: np.arange(1, 11)
+    })
+    coverage = 0.95
+
     # Test Prophet
     trained_model = Pipeline([("estimator", ProphetEstimator(coverage=coverage))])
     trained_model.fit(X, X[cst.VALUE_COL])
     forecast = get_forecast(X, trained_model)
-    # with pytest.raises(Exception):
-    #    fig = forecast.plot_components()
-    #    assert fig is not None
+    fig = forecast.plot_components()
+    assert fig is not None
