@@ -1,3 +1,4 @@
+import sys
 import warnings
 from functools import partial
 
@@ -41,6 +42,12 @@ from greykite.sklearn.estimator.silverkite_estimator import SilverkiteEstimator
 from greykite.sklearn.transform.column_selector import ColumnSelector
 
 
+try:
+    import fbprophet  # noqa
+except ModuleNotFoundError:
+    pass
+
+
 def test_get_best_index():
     """Tests `get_best_index`"""
     results = {
@@ -172,6 +179,8 @@ def test_get_default_time_parameters():
         "cv_periods_between_train_test": 5}
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_get_basic_pipeline():
     """Tests get_basic_pipeline with default parameters"""
     estimator = ProphetEstimator()
@@ -253,6 +262,8 @@ def test_get_basic_pipeline_custom():
         assert_eval_function_equal(pipeline.steps[-1][-1].score_func, expected_score_func)
 
 
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
 def test_get_basic_pipeline_apply():
     """Tests get_basic_pipeline fit and predict methods on a dataset without regressors"""
     df = generate_df_for_tests("D", 50)
@@ -735,10 +746,6 @@ def test_get_forecast():
         cst.TIME_COL: pd.date_range("2018-01-01", periods=10, freq="D"),
         cst.VALUE_COL: np.arange(10)
     })
-    X_future = pd.DataFrame({
-        cst.TIME_COL: pd.date_range("2018-01-11", periods=2, freq="D"),
-        cst.VALUE_COL: np.repeat(np.nan, 2)
-    })
     # coverage is sufficient to request uncertainty interval,
     # even with ``uncertainty_dict=None``
     coverage = 0.95
@@ -767,6 +774,22 @@ def test_get_forecast():
         assert "y_true contains 0. MedAPE is undefined." in record[1].message.args[0]
         assert "denominator contains very small values. sMAPE is likely highly volatile." in record[2].message.args[0]
 
+
+@pytest.mark.skipif("fbprophet" not in sys.modules,
+                    reason="Module 'fbprophet' not installed, pytest for 'ProphetTemplate' skipped.")
+def test_get_forecast_prophet():
+    X = pd.DataFrame({
+        cst.TIME_COL: pd.date_range("2018-01-01", periods=10, freq="D"),
+        cst.VALUE_COL: np.arange(10)
+    })
+    X_future = pd.DataFrame({
+        cst.TIME_COL: pd.date_range("2018-01-11", periods=2, freq="D"),
+        cst.VALUE_COL: np.repeat(np.nan, 2)
+    })
+    # coverage is sufficient to request uncertainty interval,
+    # even with ``uncertainty_dict=None``
+    coverage = 0.95
+
     # test forecast into future with bands and null model, custom labels, custom loss
     trained_model = Pipeline([("estimator", ProphetEstimator(
         coverage=coverage,
